# phenotron

![Build status](https://img.shields.io/github/actions/workflow/status/TheJacksonLaboratory/phenotron/python_ci.yml)

[//]: # (![PyPi downloads]&#40;https://img.shields.io/pypi/dm/hpo-toolkit.svg?label=Pypi%20downloads&#41;)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/phenotron)

A library and cli for working transforming anything to Phenopackets

## Install

Phenotron is available from PyPi:

```shell
pip install phenotron
```

## Poetry

```shell
poetry add phenotron
```

### Run tests with poetry

```shell
cd /path/to/your/phenotron
poetry run pytest
```

[//]: # (## Examples)

[//]: # ()
[//]: # (Check out the [Jupyter)

[//]: # (notebooks]&#40;https://github.com/TheJacksonLaboratory/hpo-toolkit/tree/main/notebooks&#41; for an example usage.)

## Disclaimer

`phenotron` is still in *alpha* stage, the APIs may change.
